#[non_exhaustive]pub enum DisplayOutput {
NotSignedAtAll {
path: Utf8PathBuf,
},
SignedKeys(SignedKeys),
SuccessUnimplemented {
stdout: String,
},
ErrorUnImplemented {
stderr: String,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotSignedAtAll
Considered an error case
Fields

path: Utf8PathBufSignedKeys(SignedKeys)
Successfully extracted key-value pairs from codesign -d
SuccessUnimplemented
This output variant indicates that the command exited with a status code of 0, but its exact output’s parsing code has not yet been implemented yet. PRs welcome!
ErrorUnImplemented
This output variant indicates that the command did not exit with a status code of 0, but its exact output’s parsing code has not yet been implemented yet. PRs welcome!