#[non_exhaustive]pub enum BootOutput {
AlreadyBooted,
SuccessUnImplemented {
stdout: String,
},
ErrorUnImplemented {
stderr: String,
},
ErrorLaunchDFailed {
stderr: String,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AlreadyBooted
NOT considered an error case, since the simulator is already booted.
SuccessUnImplemented
This output variant indicates that the command exited with a status code of 0, but its exact output’s parsing code has not yet been implemented yet. PRs welcome!
ErrorUnImplemented
This output variant indicates that the command did not exit with a status code of 0, but its exact output’s parsing code has not yet been implemented yet. PRs welcome!
ErrorLaunchDFailed
Added so a special recommendation of running a fixing command can be displayed:
sudo rm -rf ~/Library/Developer/CoreSimulator/CachesAn error was encountered processing the command (domain=NSPOSIXErrorDomain, code=60): Unable to boot the Simulator. launchd failed to respond. Underlying error (domain=com.apple.SimLaunchHostService.RequestError, code=4): Failed to start launchd_sim: could not bind to session, launchd_sim may have crashed or quit responding