ListOutput

Enum ListOutput 

#[non_exhaustive]
pub enum ListOutput { SuccessJson(ListJson), SuccessUnImplemented { stdout: String, }, ErrorUnImplemented { stderr: String, }, }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


SuccessJson(ListJson)

Contains the actual output of the command, parsed



SuccessUnImplemented

This output variant indicates that the command exited with a status code of 0, but its exact output’s parsing code has not yet been implemented yet. PRs welcome!

Fields

stdout: String


ErrorUnImplemented

This output variant indicates that the command did not exit with a status code of 0, but its exact output’s parsing code has not yet been implemented yet. PRs welcome!

Fields

stderr: String

Implementations

Source

impl ListOutput

pub fn success(&self) -> Result<&ListJson>

Returns Error::OutputErrored if it didn’t succeed. Used to make error handling of non-successful commands explicit

Examples found in repository?
examples/xcrun-simctl-list.rs (line 10)
3fn main() -> Result<(), apple_clis::error::Error> {
4	let xcrun_instance = apple_clis::xcrun::XcRunInstance::new()?;
5	let simctl_instance = xcrun_instance.simctl();
6
7	let output = simctl_instance.list()?;
8	println!("Output: {:#?}", output);
9
10	let devices = output.success()?.devices();
11	for device in devices {
12		println!("Device: {:#?}", device);
13	}
14
15	Ok(())
16}
More examples
Hide additional examples
examples/simctl.rs (line 8)
3fn main() -> Result<(), apple_clis::error::Error> {
4	let xcrun_instance = xcrun::XcRunInstance::new()?;
5	let simctl_instance = xcrun_instance.simctl();
6
7	let output = simctl_instance.list()?;
8	let devices: Vec<&simctl::list::ListDevice> = output.success()?.devices().collect();
9	for device in devices {
10		println!(
11			"Simulator device {name} is {state:?} and is ready = {ready:?}",
12			name = device.name,
13			state = device.state,
14			ready = device.ready()
15		);
16	}
17
18	// the .names() and .ipads() are implemented on extension traits imported with
19	// use apple_clis::prelude::*;
20	// to make finding devices easier and more ergonomic
21	let ipad_simulator: &IPadVariant = output
22		.get_success()
23		.expect("to succeed")
24		.devices()
25		.names()
26		.ipads()
27		.max()
28		.expect("an iPad simulator to be available");
29	println!("Found an {} simulator", ipad_simulator);
30
31	if let IPadVariant::Pro {
32		size, generation, ..
33	} = ipad_simulator
34	{
35		let inches: f32 = size.inches();
36		let gen: u8 = match generation {
37			// generations can be M1 or gen 6
38			Generation::Num(num) => num.get(),	
39			Generation::M(m_gen) => m_gen.get_u8(),
40		};
41		println!(
42			"Ooh, its a pro size {} {:?} generation {} {:?}",
43			size, inches, generation, gen,
44		);
45	}
46
47	// boot the simulator
48	let boot_result = simctl_instance.boot(DeviceName::from(*ipad_simulator))?;
49	match boot_result {
50		simctl::boot::BootOutput::SuccessUnImplemented { .. } => println!("Booted the simulator"),
51		simctl::boot::BootOutput::AlreadyBooted => println!("Simulator was already booted"),
52		_ => println!("PRs welcome to cover more cases"),
53	}
54
55	// open the simulator
56	let open_instance = open::OpenCLIInstance::new()?;
57	open_instance.open_well_known(&open::well_known::WellKnown::Simulator)?;
58
59	Ok(())
60}
pub fn unwrap_success(&self) -> &ListJson

pub fn get_success(&self) -> Option<&ListJson>

Examples found in repository?
examples/simctl.rs (line 22)
3fn main() -> Result<(), apple_clis::error::Error> {
4	let xcrun_instance = xcrun::XcRunInstance::new()?;
5	let simctl_instance = xcrun_instance.simctl();
6
7	let output = simctl_instance.list()?;
8	let devices: Vec<&simctl::list::ListDevice> = output.success()?.devices().collect();
9	for device in devices {
10		println!(
11			"Simulator device {name} is {state:?} and is ready = {ready:?}",
12			name = device.name,
13			state = device.state,
14			ready = device.ready()
15		);
16	}
17
18	// the .names() and .ipads() are implemented on extension traits imported with
19	// use apple_clis::prelude::*;
20	// to make finding devices easier and more ergonomic
21	let ipad_simulator: &IPadVariant = output
22		.get_success()
23		.expect("to succeed")
24		.devices()
25		.names()
26		.ipads()
27		.max()
28		.expect("an iPad simulator to be available");
29	println!("Found an {} simulator", ipad_simulator);
30
31	if let IPadVariant::Pro {
32		size, generation, ..
33	} = ipad_simulator
34	{
35		let inches: f32 = size.inches();
36		let gen: u8 = match generation {
37			// generations can be M1 or gen 6
38			Generation::Num(num) => num.get(),	
39			Generation::M(m_gen) => m_gen.get_u8(),
40		};
41		println!(
42			"Ooh, its a pro size {} {:?} generation {} {:?}",
43			size, inches, generation, gen,
44		);
45	}
46
47	// boot the simulator
48	let boot_result = simctl_instance.boot(DeviceName::from(*ipad_simulator))?;
49	match boot_result {
50		simctl::boot::BootOutput::SuccessUnImplemented { .. } => println!("Booted the simulator"),
51		simctl::boot::BootOutput::AlreadyBooted => println!("Simulator was already booted"),
52		_ => println!("PRs welcome to cover more cases"),
53	}
54
55	// open the simulator
56	let open_instance = open::OpenCLIInstance::new()?;
57	open_instance.open_well_known(&open::well_known::WellKnown::Simulator)?;
58
59	Ok(())
60}
pub fn get_success_reported(&self) -> Result<&ListJson, Report>

Only used in CLI prefer Self::get_success